@@ -33,14 +33,14 @@ import os
 
 import tensorflow as tf
 
-from deepcell_toolbox.processing import normalize
+from deepcell_toolbox.processing import histogram_normalization
 from deepcell_toolbox.deep_watershed import deep_watershed
 
 from deepcell.applications import Application
 
 
 MODEL_PATH = ('https://deepcell-data.s3-us-west-1.amazonaws.com/'
-              'saved-models/CytoplasmSegmentation-2.tar.gz')
+              'saved-models/CytoplasmSegmentation-3.tar.gz')
 
 
 class CytoplasmSegmentation(Application):
@@ -92,12 +92,14 @@ class CytoplasmSegmentation(Application):
         'validation_steps_per_epoch': 1973 // 2
     }
 
-    def __init__(self, model=None):
+    def __init__(self, model=None,
+                 preprocessing_fn=histogram_normalization,
+                 postprocessing_fn=deep_watershed):
 
         if model is None:
             archive_path = tf.keras.utils.get_file(
                 'CytoplasmSegmentation.tgz', MODEL_PATH,
-                file_hash='4536223e6ce160e8a8b67e4f45d5a5ef',
+                file_hash='3a44131177f2c66457bad444d8973708',
                 extract=True, cache_subdir='models'
             )
             model_path = os.path.splitext(archive_path)[0]
@@ -107,8 +109,8 @@ class CytoplasmSegmentation(Application):
             model,
             model_image_shape=model.input_shape[1:],
             model_mpp=0.65,
-            preprocessing_fn=normalize,
-            postprocessing_fn=deep_watershed,
+            preprocessing_fn=preprocessing_fn,
+            postprocessing_fn=postprocessing_fn,
             dataset_metadata=self.dataset_metadata,
             model_metadata=self.model_metadata)
 
@@ -116,8 +118,9 @@ class CytoplasmSegmentation(Application):
                 image,
                 batch_size=4,
                 image_mpp=None,
-                preprocess_kwargs={},
-                postprocess_kwargs={}):
+                pad_mode='reflect',
+                preprocess_kwargs=None,
+                postprocess_kwargs=None):
         """Generates a labeled image of the input running prediction with
         appropriate pre and post processing functions.
 
@@ -131,6 +134,7 @@ class CytoplasmSegmentation(Application):
                 ``[batch, x, y, channel]``.
             batch_size (int): Number of images to predict on per batch.
             image_mpp (float): Microns per pixel for ``image``.
+            pad_mode (str): The padding mode, one of "constant" or "reflect".
             preprocess_kwargs (dict): Keyword arguments to pass to the
                 pre-processing function.
             postprocess_kwargs (dict): Keyword arguments to pass to the
@@ -146,9 +150,22 @@ class CytoplasmSegmentation(Application):
         Returns:
             numpy.array: Labeled image
         """
+        if preprocess_kwargs is None:
+            preprocess_kwargs = {}
+
+        if postprocess_kwargs is None:
+            postprocess_kwargs = {
+                'radius': 10,
+                'maxima_threshold': 0.1,
+                'interior_threshold': 0.01,
+                'exclude_border': False,
+                'small_objects_threshold': 0
+            }
+
         return self._predict_segmentation(
             image,
             batch_size=batch_size,
             image_mpp=image_mpp,
+            pad_mode=pad_mode,
             preprocess_kwargs=preprocess_kwargs,
             postprocess_kwargs=postprocess_kwargs)
